# grohe
A python package to interact with the Grohe API. 

## License
This project is licensed under the <MIT> [MIT](https://github.com/koproductions-code/groheblue/blob/master/LICENSE) License - see LICENSE file for details.

